@@ -3,7 +3,7 @@ from emannotationschemas.schemas.synapse import PlasticSynapse
 from emannotationschemas.schemas.synapse import BuhmannSynapseSchema
 from emannotationschemas.schemas.synapse import BuhmannEcksteinSynapseSchema
 from emannotationschemas.schemas.presynaptic_bouton_type import PresynapticBoutonType
-from emannotationschemas.schemas.functional_coregistration import FunctionalCoregistration
+from emannotationschemas.schemas.functional_coregistration import FunctionalCoregistration, FunctionalUnitCoregistration
 from emannotationschemas.schemas.postsynaptic_compartment import PostsynapticCompartment
 from emannotationschemas.schemas.base import FlatSegmentationReferenceSinglePoint
 from emannotationschemas.schemas.cell_type_local import CellTypeLocal
@@ -12,10 +12,11 @@ from emannotationschemas.schemas.glia_contact import GliaContact
 from emannotationschemas.schemas.contact import Contact
 from emannotationschemas.schemas.extended_classical_cell_type import ExtendedClassicalCellType
 from emannotationschemas.schemas.nucleus_detection import NucleusDetection
+from emannotationschemas.schemas.derived_spatial_point import DerivedSpatialPoint, DerivedTag
 from emannotationschemas.errors import UnknownAnnotationTypeException
 from emannotationschemas.flatten import create_flattened_schema
 
-__version__ = '3.0.0'
+__version__ = '3.1.7'
 
 type_mapping = {
     'synapse': SynapseSchema,
@@ -24,6 +25,7 @@ type_mapping = {
     'presynaptic_bouton_type': PresynapticBoutonType,
     'postsynaptic_compartment': PostsynapticCompartment,
     'microns_func_coreg': FunctionalCoregistration,
+    'microns_func_unit_coreg': FunctionalUnitCoregistration,
     'cell_type_local': CellTypeLocal,
     'nucleus_detection': NucleusDetection,
     'bound_tag': BoundTagAnnotation,
@@ -31,6 +33,8 @@ type_mapping = {
     'plastic_synapse': PlasticSynapse,
     'glia_contact': GliaContact,
     'contact': Contact,
+    'derived_spatial_point': DerivedSpatialPoint,
+    'derived_tag': DerivedTag,
 }
 
 
@@ -60,17 +64,17 @@ def get_schema(schema_type: str):
     try:
         return type_mapping[schema_type]
     except KeyError:
-        msg = 'type {} is not a known annotation type'.format(schema_type)
+        msg = f"Schema type: {schema_type} is not a known annotation type"
         raise UnknownAnnotationTypeException(msg)
 
 
-def get_flat_schema(type):
+def get_flat_schema(schema_type: str):
     try:
-        Schema = type_mapping[type]
+        Schema = type_mapping[schema_type]
         FlatSchema = create_flattened_schema(Schema)
         return FlatSchema
     except KeyError:
-        msg = 'type {} is not a known annotation type'.format(type)
+        msg = f"Schema type: {schema_type} is not a known annotation type"
         raise UnknownAnnotationTypeException(msg)
 
 
@@ -81,12 +85,13 @@ def create_app(test_config=None):
     from emannotationschemas.config import configure_app
     from emannotationschemas.utils import get_instance_folder_path
 
-    from emannotationschemas.blueprint_app import api_bp 
+    from emannotationschemas.blueprint_app import api_bp
     from emannotationschemas.views import views_bp
     import logging
     # Define the Flask Object
     app = Flask(__name__,
                 instance_path=get_instance_folder_path(),
+                static_url_path='/schema/static',
                 instance_relative_config=True)
 
     logging.basicConfig(level=logging.DEBUG)
@@ -98,10 +103,20 @@ def create_app(test_config=None):
         app.config.update(test_config)
 
     apibp = Blueprint('api', __name__, url_prefix='/schema/api')
+   
+    @app.route('/schema/versions')
+    def versions():
+        return jsonify([2]), 200
+
+    @app.route("/schema/")
+    def index():
+        return redirect("/schema/views")
+
     with app.app_context():
-        api = Api(apibp, title="EMAnnotationSchemas API", version=__version__, doc="/doc")
+        api = Api(apibp, title="EMAnnotationSchemas API",
+                  version=__version__, doc="/doc")
         api.add_namespace(api_bp, path='/v2')
         app.register_blueprint(apibp)
         app.register_blueprint(views_bp)
 
-    return app
\ No newline at end of file
+    return app
